#
# Copyright 2017 Canonical Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import charms_openstack.charm as charm
import charms.reactive as reactive
import charm.openstack.ucarp as ucarp
import charmhelpers.core.hookenv as hookenv

charm.use_defaults(
    'charm.installed',
    'config.changed')


@reactive.when('charm.installed')
@reactive.when('config.changed')
def render_config(*args):
    with charm.provide_charm_instance() as charm_class:
        charm_class.render_with_interfaces(args)
        vip_ip_address = hookenv.config('vip_ip_address')
        vip_ip_mask = hookenv.config('vip_ip_mask')
        vip_vid = hookenv.config('vip_vid')
        nic = hookenv.config('nic')
        if vip_ip_address == "":
            hookenv.status_set('blocked', 'vip_ip_address not set, '
                               'redundancy disabled')
        elif not ucarp.check_nic(nic):
            hookenv.status_set('blocked', 'config nic="{}" not found, '
                               'redundancy disabled'.format(nic))
        else:
            msg = "vid: {}, addr: {}, mask: {}".format(vip_vid, 
                                                       vip_ip_address,
                                                       vip_ip_mask)
            hookenv.status_set('active', msg)
    reactive.set_state('config.rendered')
